@@ -41,9 +41,7 @@ where
                 })
                 .unwrap_or(false)
             {
-                if cfg!(feature = "debug") {
-                    tracing::trace!("[x] bad usage");
-                }
+                log_abort!("[x] bad usage");
                 return;
             }
 
@@ -87,9 +85,7 @@ where
             }
 
             if !unknown_used_props.is_empty() {
-                if cfg!(feature = "debug") {
-                    tracing::trace!("[x] unknown used props: {:?}", unknown_used_props);
-                }
+                log_abort!("[x] unknown used props: {:?}", unknown_used_props);
                 return;
             }
 
@@ -115,7 +111,7 @@ where
 
                         match &p.key {
                             PropName::Str(s) => {
-                                tracing::debug!(
+                                trace_op!(
                                     "hoist_props: Storing a variable (`{}`) to inline properties",
                                     name.id
                                 );
@@ -124,7 +120,7 @@ where
                                 self.mode.store(name.to_id(), n.init.as_deref().unwrap());
                             }
                             PropName::Ident(i) => {
-                                tracing::debug!(
+                                trace_op!(
                                     "hoist_props: Storing a variable(`{}`) to inline properties",
                                     name.id
                                 );
@@ -177,7 +173,7 @@ where
                     );
                 }
                 None => {
-                    tracing::debug!(
+                    trace_op!(
                         "hoist_props: Stored {}{:?} to inline property access",
                         name.id.sym,
                         name.id.span.ctxt
@@ -204,7 +200,7 @@ where
                         f.function.span = DUMMY_SP;
                     }
 
-                    tracing::debug!("hoist_props: Inlining `{}.{}`", obj.sym, prop.sym);
+                    report_change!("hoist_props: Inlining `{}.{}`", obj.sym, prop.sym);
                     self.changed = true;
                     *e = *value;
                     return;
@@ -214,7 +210,7 @@ where
             if let Some(value) = self.vars_for_prop_hoisting.remove(&obj.to_id()) {
                 member.obj = value;
                 self.changed = true;
-                tracing::debug!("hoist_props: Inlined a property");
+                report_change!("hoist_props: Inlined a property");
             }
         }
     }
